import React, { CSSProperties, ChangeEvent, MouseEventHandler } from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';

interface FormSpecProps {
    data: FormDataType;
    updateData: FormDataUpdateType;
    resetData: FormDataResetType;
}
interface FormProps extends Omit<React.DetailedHTMLProps<React.FormHTMLAttributes<HTMLFormElement>, HTMLFormElement>, 'onSubmit'> {
    formSpecs: (props: FormSpecProps) => FormFieldAttrType[];
    onSubmit: (isFormValid: boolean, data: FormDataType) => void;
}
interface FormInputValidatorType {
    message: string;
    validate: (value: string) => boolean;
}
interface CommonInputFieldAttr extends React.InputHTMLAttributes<HTMLInputElement> {
    id: string;
    label?: string;
    value?: string;
    required?: boolean;
    className?: string;
    style?: CSSProperties;
    onChange?: (event: ChangeEvent<HTMLInputElement>) => void;
    validator?: FormInputValidatorType[];
}
interface InputFieldAttr extends CommonInputFieldAttr {
    type: 'text' | 'email' | 'date' | 'time' | 'datetime-local' | 'password' | 'color' | 'file';
}
interface RadioButtonFieldAttr extends CommonInputFieldAttr {
    type: 'radio';
    options: string[];
}
interface CheckboxFieldAttr extends Omit<CommonInputFieldAttr, 'value'> {
    type: 'checkbox';
    checked?: boolean;
}
interface DropdownFieldAttr {
    type: "dropdown";
    id: string;
    label?: string;
    options: string[];
    value?: string;
    required?: boolean;
    disabled?: boolean;
    className?: string;
    style?: CSSProperties;
    onSelect?: (option: string) => void;
    emptyText?: string;
}
interface CommonButtonFieldAttr extends Omit<React.ButtonHTMLAttributes<HTMLButtonElement>, 'onChange' | 'label'> {
    id: string;
    value: string;
    onClick: MouseEventHandler<HTMLButtonElement>;
}
interface ButtonFieldAtt extends CommonButtonFieldAttr {
    type: 'button';
}
interface SubmitFieldAttr extends Omit<CommonButtonFieldAttr, 'onClick'> {
    type: 'submit';
}
interface CommonLayoutFieldAttr extends React.HTMLAttributes<HTMLDivElement> {
    id: string;
    fields: FormFieldAttrType[];
}
interface FormRowLayoutFieldAttr extends CommonLayoutFieldAttr {
    type: "row-layout";
}
interface FormColLayoutFieldAttr extends CommonLayoutFieldAttr {
    type: "col-layout";
}
type FormInputFieldAttr = InputFieldAttr | RadioButtonFieldAttr | CheckboxFieldAttr | DropdownFieldAttr;
type FormButtonFieldAttr = ButtonFieldAtt | SubmitFieldAttr;
type FormLayoutFieldAttr = FormRowLayoutFieldAttr | FormColLayoutFieldAttr;
type FormFieldAttrType = FormInputFieldAttr | FormButtonFieldAttr | FormLayoutFieldAttr;
interface FormDataType {
    [key: string]: {
        value: string;
        valid: boolean;
        error: string;
    };
}
interface FormDataUpdateType {
    (data: FormDataType): void;
}
interface FormDataResetType {
    (): void;
}

declare function Form(props: FormProps): react_jsx_runtime.JSX.Element;

export { type ButtonFieldAtt, type CheckboxFieldAttr, type DropdownFieldAttr, Form, type FormButtonFieldAttr, type FormDataResetType, type FormDataType, type FormDataUpdateType, type FormFieldAttrType, type FormInputValidatorType, type FormLayoutFieldAttr, type FormProps, type FormSpecProps, type InputFieldAttr, type RadioButtonFieldAttr, type SubmitFieldAttr };
